package Daje::Plugin::Companies::Languages;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Companies::Languages - Model class
#
# SYNOPSIS
# ========
#
#
#
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Companies::Languages is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-03-15 11:17:38.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-03-15 11:17:38 -->

use Daje::Helper::Languages::InsertKeys;

has 'db';

sub language($self) {

    try {
        my $tx = $self->db->begin;
        my @keys;
        push @keys, {
                plugin => 'companies',
                key => 'users',
                field => 'table',
                type => 'Label',
                translation => '',
                comment => '',
            };
          push @keys,  {
                plugin => 'companies',
                key => 'users',
                field => 'comment',
                type => 'Label',
                translation => 'Comment',
                comment => 'Comment'
            };
           push @keys, {
                plugin => 'companies',
                key => 'users',
                field => 'comment',
                type => 'Tool tips',
                translation => 'Comment',
                comment => 'Comment'
            };
         
          push @keys,  {
                plugin => 'companies',
                key => 'users',
                field => 'companies',
                type => 'Label',
                translation => '',
                comment => ''
            };
           push @keys, {
                plugin => 'companies',
                key => 'users',
                field => 'companies',
                type => 'Tool tips',
                translation => '',
                comment => ''
            };
         
          push @keys,  {
                plugin => 'companies',
                key => 'users',
                field => 'users',
                type => 'Label',
                translation => '',
                comment => ''
            };
           push @keys, {
                plugin => 'companies',
                key => 'users',
                field => 'users',
                type => 'Tool tips',
                translation => '',
                comment => ''
            };
         
        push @keys, {
                plugin => 'companies',
                key => 'companies',
                field => 'table',
                type => 'Label',
                translation => 'Companies',
                comment => 'Companies table',
            };
          push @keys,  {
                plugin => 'companies',
                key => 'companies',
                field => 'registrationnumber',
                type => 'Label',
                translation => 'Registration number',
                comment => 'Registration number'
            };
           push @keys, {
                plugin => 'companies',
                key => 'companies',
                field => 'registrationnumber',
                type => 'Tool tips',
                translation => 'Registration number',
                comment => 'Registration number'
            };
         
          push @keys,  {
                plugin => 'companies',
                key => 'companies',
                field => 'homepage',
                type => 'Label',
                translation => 'Homepage',
                comment => 'Company homepage'
            };
           push @keys, {
                plugin => 'companies',
                key => 'companies',
                field => 'homepage',
                type => 'Tool tips',
                translation => 'Company homepage',
                comment => 'Company homepage'
            };
         
          push @keys,  {
                plugin => 'companies',
                key => 'companies',
                field => 'active',
                type => 'Label',
                translation => 'Active',
                comment => 'Is the company active ?'
            };
           push @keys, {
                plugin => 'companies',
                key => 'companies',
                field => 'active',
                type => 'Tool tips',
                translation => 'Is the company active ?',
                comment => 'Is the company active ?'
            };
         
          push @keys,  {
                plugin => 'companies',
                key => 'companies',
                field => 'boards_office',
                type => 'Label',
                translation => 'Boards office',
                comment => 'Boards office official address'
            };
           push @keys, {
                plugin => 'companies',
                key => 'companies',
                field => 'boards_office',
                type => 'Tool tips',
                translation => 'Boards office official address',
                comment => 'Boards office official address'
            };
         
          push @keys,  {
                plugin => 'companies',
                key => 'companies',
                field => 'workflow',
                type => 'Label',
                translation => '',
                comment => ''
            };
           push @keys, {
                plugin => 'companies',
                key => 'companies',
                field => 'workflow',
                type => 'Tool tips',
                translation => '',
                comment => ''
            };
         
          push @keys,  {
                plugin => 'companies',
                key => 'companies',
                field => 'name',
                type => 'Label',
                translation => 'Name',
                comment => 'Company name'
            };
           push @keys, {
                plugin => 'companies',
                key => 'companies',
                field => 'name',
                type => 'Tool tips',
                translation => 'Company name',
                comment => 'Company name'
            };
         

        Daje::Helper::Languages::InsertKeys->new(
            db => $self->db
        )->process(
             \@keys
        );
        $tx->commit();
    } catch($e) {
        say $e;
    }
}

1;


