package Daje::Plugin::Companies::Routes;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Companies::Routes - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Companies::Routes;
#
#       my $class = Daje::Plugin::Companies::Routes->new();
#       $r->get('/companies/api/v1/users/:companies_users_pkey');
#       $r->get('/companies/api/v1/users_companies/:companies_companies_fkey');

       
#       $r->get('/companies/api/v1/users_users/:companies_users_fkey');

       
#       $r->get('/companies/api/v1/companies/:companies_companies_pkey');
#       $r->get('/companies/api/v1/companies_workflow/:companies_workflow_fkey');

       #
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Companies::Routes is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-03-15 11:17:38.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-03-15 11:17:38 -->

our $VERSION = '0.01';

sub routes($self, $app, $config) {
    my $r = $app->auth;

    $r->get('v1/users_list_all/')->to('CompaniesUsersList#load_all_companies_users');
    $r->get('v1/users_companies_list/:companies_companies_fkey')->to('CompaniesUsers#load_list_companies_companies_fkey');
    $r->get('v1/users_users_list/:users_users_fkey')->to('CompaniesUsers#load_list_users_users_fkey');
    $r->get('v1/companies_list_all/')->to('CompaniesCompaniesList#load_all_companies_companies');
    $r->get('v1/companies_workflow_list/:companies_workflow_fkey')->to('CompaniesCompanies#load_list_companies_workflow_fkey');

    $r->get('v1/users_companies/:companies_companies_fkey')->to('CompaniesUsers#load_companies_companies_fkey');
    $r->get('v1/users_users/:companies_users_fkey')->to('CompaniesUsers#load_companies_users_fkey');    $r->get('v1/users/:companies_users_pkey')->to('CompaniesUsers#load_companies_users_pkey');
    $r->get('v1/companies_workflow/:companies_workflow_fkey')->to('CompaniesCompanies#load_companies_workflow_fkey');    $r->get('v1/companies/:companies_companies_pkey')->to('CompaniesCompanies#load_companies_companies_pkey');
}

