package Daje::Plugin::Companies::Helpers;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Companies::Helpers - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Companies::Helpers;
#
#       my $class = Daje::Plugin::Companies::Helpers->new();
#       $app->helper(
#           v_companies_users => sub {
#               state  $v_companies_users = Daje::Database::Model::vCompaniesUsers->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_companies_companies => sub {
#               state  $v_companies_companies = Daje::Database::Model::vCompaniesCompanies->new(db => shift->pg->db)
#        });#
#       $app->helper(
#           v_companies_users_list => sub {
#               state  $v_companies_users_list = Daje::Database::Model::vCompaniesUsersList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_companies_companies_list => sub {
#               state  $v_companies_companies_list = Daje::Database::Model::vCompaniesCompaniesList->new(db => shift->pg->db)
#        });#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Companies::Helpers is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-03-15 11:17:38.
# It will be re-generated by Daje Tools again.
# <!-- Autogenerated file 2026-03-15 11:17:38 -->

use Daje::Database::View::vCompaniesUsers;
use Daje::Database::View::vCompaniesCompanies;# Lists
use Daje::Database::View::vCompaniesUsersList;
use Daje::Database::View::vCompaniesCompaniesList;

our $VERSION = '0.01';

sub helpers($self, $app, $config) {

    $app->helper(
        v_companies_users => sub {
            state  $v_companies_users = Daje::Database::View::vCompaniesUsers->new(db => shift->pg->db)
        });
    $app->helper(
        v_companies_companies => sub {
            state  $v_companies_companies = Daje::Database::View::vCompaniesCompanies->new(db => shift->pg->db)
        });    # Lists
    $app->helper(
        v_companies_users_list => sub {
            state  $v_companies_users_list = Daje::Database::View::vCompaniesUsersList->new(db => shift->pg->db)
        });
    $app->helper(
        v_companies_companies_list => sub {
            state  $v_companies_companies_list = Daje::Database::View::vCompaniesCompaniesList->new(db => shift->pg->db)
        });}

1;



