package Daje::Database::View::Super::vCompaniesCompanies;
use Mojo::Base 'Daje::Database::Model::Super::Common::Base', -base, -signatures, -async_await;
use v5.42;

# NAME
# ====
#
# Daje::Database::View::Super::vCompaniesCompanies - Daje db model
#
# SYNOPSIS
# ========
#
#
#       use Daje::Database::View::Super::vCompaniesCompanies;
#
#       my $table = Daje::Database::View::Super::vCompaniesCompanies->new(db => $db);
#
#       my $result = $table->load_companies_companies_pkey($self, $companies_companies_pkey);
#
#       my $result = $table->load_companies_workflow_fkey($self, $companies_workflow_fkey);
##
#
#
# DESCRIPTION
# ===========
#
# Daje::Database::View::Super::vCompaniesCompanies is a View super class
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-03-15 11:17:37.
# It will be re-created by Daje Tools again and any changes
# will be over written.
#
# <!-- Autogenerated file 2026-03-15 11:17:37 -->

our $VERSION = '0.01';

has 'fields' => '"companies_companies_pkey", "editnum", "insby", "insdatetime", "modby", "moddatetime","registrationnumber","homepage","active","boards_office","companies_workflow_fkey","name"';
has 'primary_key_name' => "companies_companies_pkey";
has 'table_name' => "v_companies_companies";


async sub load_companies_workflow_fkey_p($self, $companies_workflow_fkey) {
    return $self->load_companies_workflow_fkey($companies_workflow_fkey);
}

sub load_companies_workflow_fkey($self, $companies_workflow_fkey) {
    return $self->load_fkey(
        $self->table_name, $self->fields(), "companies_workflow_fkey", $companies_workflow_fkey
    );
}
async sub load_companies_companies_pkey_p($self, $companies_companies_pkey) {
    return $self->load_companies_companies_pkey($companies_companies_pkey);
}

sub load_companies_companies_pkey($self, $companies_companies_pkey) {
    return $self->load_pk(
        $self->table_name, $self->fields(), $self->primary_key_name(), $companies_companies_pkey
    );
}

1;

